@@ -4,6 +4,7 @@ from .Core.List import *
 from .Core.Terminal import *
 
 BS4_SETTING = 'html.parser'
+BS4_FEATURES = "lxml"
 
 class Scraper:
     """
@@ -21,7 +22,7 @@ class Scraper:
         self.date = None
         self.url = resonpse.url
         self.origin = self.response.origin
-        self._soup = BeautifulSoup(resonpse.text, BS4_SETTING)
+        self._soup = BeautifulSoup(resonpse.text, BS4_SETTING, features = BS4_FEATURES)
         self.title = self.getTitle()
 
     def getTitle(self) -> str:
@@ -62,7 +63,7 @@ class Scraper:
         """
         Returns a list of links
         """
-        return List(str).extend([str(a.get('href')) for a in self._soup.find_all('a')])
+        return List(str).extend([str(a['href']) for a in self._soup.find_all('a', href = True)])
 
     def __str__(self):
         return f"""
